"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadConfig = loadConfig;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const defaultConfig = {
    prefix: 'attr_',
    presets: []
};
let cachedConfig = null;
const processPresets = (presets) => {
    return presets.map(preset => {
        if (typeof preset === 'function') {
            return preset();
        }
        return preset;
    });
};
function loadConfig(cwd) {
    if (cachedConfig) {
        return cachedConfig;
    }
    const configPath = path_1.default.resolve(cwd, 'attributify.config.js');
    if (fs_1.default.existsSync(configPath)) {
        try {
            delete require.cache[configPath];
            // eslint-disable-next-line @typescript-eslint/no-require-imports
            const userConfig = require(configPath);
            cachedConfig = {
                prefix: userConfig.prefix || defaultConfig.prefix,
                presets: processPresets(userConfig.presets)
            };
            return cachedConfig;
        }
        catch (error) {
            console.warn(`Error while reading config file: ${configPath}`, error);
        }
    }
    cachedConfig = defaultConfig;
    return cachedConfig;
}
//# sourceMappingURL=config.js.map