"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = default_1;
const core_1 = require("@babel/core");
const config_1 = require("./config");
const checkStyleSheetExistence_1 = require("./utils/checkStyleSheetExistence");
const extractRelativePath_1 = require("./utils/extractRelativePath");
const generateStyleSheet_1 = require("./utils/generateStyleSheet");
const initializePatterns_1 = require("./utils/initializePatterns");
const ensureStyleSheetImport_1 = require("./utils/ensureStyleSheetImport");
const processJSXElements_1 = require("./utils/processJSXElements");
function default_1() {
    const config = (0, config_1.loadConfig)(process.cwd());
    const prefix = config.prefix;
    const patterns = (0, initializePatterns_1.initializePatterns)(config);
    return {
        name: 'babel-plugin-react-native-attributify',
        visitor: {
            Program(path, state) {
                if (patterns.length === 0)
                    return;
                const filename = state.filename || 'unknown';
                const projectRoot = process.cwd();
                const relativePath = (0, extractRelativePath_1.extractRelativePath)(filename, projectRoot);
                const styleSheetName = `${prefix}${relativePath.replace(/[^a-zA-Z0-9]/g, '_')}`;
                const styles = {};
                if ((0, checkStyleSheetExistence_1.checkStyleSheetExistence)(path))
                    return;
                (0, processJSXElements_1.processJSXElements)(path, patterns, styles, styleSheetName, core_1.types, prefix);
                if (Object.keys(styles).length > 0) {
                    const styleSheet = (0, generateStyleSheet_1.generateStyleSheet)(styles, styleSheetName, core_1.types);
                    (0, ensureStyleSheetImport_1.ensureStyleSheetImport)(path, core_1.types);
                    const lastImportIndex = path.node.body.reduce((index, node, currentIndex) => core_1.types.isImportDeclaration(node) ? currentIndex : index, -1);
                    path.node.body.splice(lastImportIndex + 1, 0, styleSheet);
                }
            }
        }
    };
}
//# sourceMappingURL=index.js.map