"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const decorationStyles = ['solid', 'double', 'dotted', 'dashed'];
const lineStyles = ['none', 'underline', 'line-through'];
const parseFontSize = (value) => {
    if (value.endsWith('px')) {
        return Number(value.slice(0, -2));
    }
    if (value.endsWith('rem')) {
        return value;
    }
    if (value.endsWith('em')) {
        return value;
    }
    return Number(value);
};
const parseTextStyle = (value) => {
    const parts = value.split(' ');
    const styles = {};
    let isDecorationContext = false;
    parts.forEach((part) => {
        if (part === 'decoration') {
            isDecorationContext = true;
            return;
        }
        if (part.match(/^[0-9]+(?:px|rem|em)?$/)) {
            styles.fontSize = parseFontSize(part);
            return;
        }
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        if (lineStyles.includes(part)) {
            styles.textDecorationLine = part;
            return;
        }
        if (decorationStyles.includes(part)) {
            styles.textDecorationStyle = part;
            return;
        }
        if (part.match(/^(#|rgb|rgba)/) || /^[a-zA-Z]+$/.test(part)) {
            if (isDecorationContext || styles.textDecorationLine) {
                styles.textDecorationColor = part;
            }
            else {
                styles.color = part;
            }
            return;
        }
    });
    return styles;
};
const textDecorations = [
    ['text', ([_, value]) => parseTextStyle(value)]
];
exports.default = textDecorations;
//# sourceMappingURL=decoration.js.map