"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const parseSizeValue = (value) => {
    if (!isNaN(Number(value))) {
        return Number(value);
    }
    switch (value) {
        case 'full':
            return '100%';
        case 'screen':
            return '100%';
        case 'half':
            return '50%';
        case 'auto':
            return 'auto';
        default:
            return value;
    }
};
const sizeRules = [
    ['w', ([_, value]) => ({
            width: parseSizeValue(value)
        })],
    ['h', ([_, value]) => ({
            height: parseSizeValue(value)
        })],
    ['min-w', ([_, value]) => ({
            minWidth: parseSizeValue(value)
        })],
    ['max-w', ([_, value]) => ({
            maxWidth: parseSizeValue(value)
        })],
    ['min-h', ([_, value]) => ({
            minHeight: parseSizeValue(value)
        })],
    ['max-h', ([_, value]) => ({
            maxHeight: parseSizeValue(value)
        })],
    ['size', ([_, value]) => {
            const parts = value.split(' ');
            const styles = {};
            if (parts.length === 1) {
                const size = parseSizeValue(parts[0]);
                styles.width = size;
                styles.height = size;
            }
            else if (parts.length === 2) {
                styles.width = parseSizeValue(parts[0]);
                styles.height = parseSizeValue(parts[1]);
            }
            else if (parts.length === 3 && parts[1] === 'x') {
                styles.width = parseSizeValue(parts[0]);
                styles.height = parseSizeValue(parts[2]);
            }
            return styles;
        }],
    ['aspect', ([_, ratio]) => {
            let aspectRatio = 1;
            if (ratio.includes('/')) {
                const [width, height] = ratio.split('/').map(Number);
                if (!isNaN(width) && !isNaN(height) && height !== 0) {
                    aspectRatio = width / height;
                }
            }
            else {
                switch (ratio) {
                    case 'square':
                        aspectRatio = 1;
                        break;
                    case 'video':
                        aspectRatio = 16 / 9;
                        break;
                    default:
                        if (!isNaN(Number(ratio)))
                            aspectRatio = Number(ratio);
                }
            }
            return { aspectRatio };
        }]
];
exports.default = sizeRules;
//# sourceMappingURL=size.js.map