"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const parseSpacingValue = (value) => {
    if (/^-?\d+(\.\d+)?(?:dp|%|vw|vh)$/.test(value)) {
        return value;
    }
    const num = Number(value);
    if (!isNaN(num)) {
        return num;
    }
    return value;
};
const handleSpacingValues = (value) => {
    const styles = {};
    const parts = value.trim().split(/\s+/);
    parts.forEach(part => {
        const [direction, size] = part.split('-');
        if (!direction || !size)
            return;
        switch (direction) {
            case 'x':
                styles.Left = parseSpacingValue(size);
                styles.Right = parseSpacingValue(size);
                break;
            case 'y':
                styles.Top = parseSpacingValue(size);
                styles.Bottom = parseSpacingValue(size);
                break;
            case 't':
                styles.Top = parseSpacingValue(size);
                break;
            case 'b':
                styles.Bottom = parseSpacingValue(size);
                break;
            case 'l':
                styles.Left = parseSpacingValue(size);
                break;
            case 'r':
                styles.Right = parseSpacingValue(size);
                break;
        }
    });
    return Object.keys(styles).length ? styles : { all: parseSpacingValue(value) };
};
const spacing = [
    ['p', ([_, value]) => {
            const spacings = handleSpacingValues(value);
            const styles = {};
            Object.entries(spacings).forEach(([key, val]) => {
                if (key === 'all') {
                    styles.padding = val;
                }
                else {
                    styles[`padding${key}`] = val;
                }
            });
            return styles;
        }],
    ['m', ([_, value]) => {
            const spacings = handleSpacingValues(value);
            const styles = {};
            Object.entries(spacings).forEach(([key, val]) => {
                if (key === 'all') {
                    styles.margin = val;
                }
                else {
                    styles[`margin${key}`] = val;
                }
            });
            return styles;
        }],
    ['pt', ([_, value]) => ({ paddingTop: parseSpacingValue(value) })],
    ['pr', ([_, value]) => ({ paddingRight: parseSpacingValue(value) })],
    ['pb', ([_, value]) => ({ paddingBottom: parseSpacingValue(value) })],
    ['pl', ([_, value]) => ({ paddingLeft: parseSpacingValue(value) })],
    ['px', ([_, value]) => ({
            paddingLeft: parseSpacingValue(value),
            paddingRight: parseSpacingValue(value)
        })],
    ['py', ([_, value]) => ({
            paddingTop: parseSpacingValue(value),
            paddingBottom: parseSpacingValue(value)
        })],
    ['mt', ([_, value]) => ({ marginTop: parseSpacingValue(value) })],
    ['mr', ([_, value]) => ({ marginRight: parseSpacingValue(value) })],
    ['mb', ([_, value]) => ({ marginBottom: parseSpacingValue(value) })],
    ['ml', ([_, value]) => ({ marginLeft: parseSpacingValue(value) })],
    ['mx', ([_, value]) => ({
            marginLeft: parseSpacingValue(value),
            marginRight: parseSpacingValue(value)
        })],
    ['my', ([_, value]) => ({
            marginTop: parseSpacingValue(value),
            marginBottom: parseSpacingValue(value)
        })]
];
exports.default = spacing;
//# sourceMappingURL=spacing.js.map