"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const processValue = (value) => {
    const fractionMatch = value.match(/(-?\d+)\/(\d+)/);
    if (fractionMatch) {
        const [_, numerator, denominator] = fractionMatch;
        const percentage = (Number(numerator) / Number(denominator)) * 100;
        return `${percentage}%`;
    }
    return value;
};
const processTransformValue = (transform) => {
    const transformFunctions = transform.match(/\w+\([^)]+\)/g) || [];
    return transformFunctions.map(func => {
        const matched = func.match(/(\w+)\(([^)]+)\)/);
        if (!matched)
            return func;
        const [_, funcName, value] = matched;
        if (funcName === 'skewX' || funcName === 'skewY') {
            const processed = processValue(value.trim());
            return `${funcName}(${processed.includes('deg') ? processed : `${processed}deg`})`;
        }
        const processedValue = processValue(value.trim());
        return `${funcName}(${processedValue})`;
    }).join(' ');
};
const transform = [
    ['transform',
        ([_, value]) => {
            try {
                const processedTransform = processTransformValue(value);
                return {
                    transform: processedTransform
                };
            }
            catch (error) {
                return {
                    transform: 'none'
                };
            }
        }]
];
exports.default = transform;
//# sourceMappingURL=transform.js.map