"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processConditionalExpression = void 0;
const processConditionalExpression = (expression, attrName, patterns, types) => {
    for (const [matcher, handler] of patterns) {
        const matchesPattern = typeof matcher === 'string'
            ? attrName === matcher
            : matcher.test(`${attrName}=""`);
        if (matchesPattern && typeof handler === 'function') {
            const { consequentStyle, alternateStyle } = getConditionalStyles(expression, attrName, handler, types);
            return createConditionalStyleObject(consequentStyle, alternateStyle, expression.test, types);
        }
    }
    return null;
};
exports.processConditionalExpression = processConditionalExpression;
const getConditionalStyles = (expression, attrName, handler, types) => {
    let consequentStyle = {};
    let alternateStyle = {};
    if (types.isStringLiteral(expression.consequent)) {
        consequentStyle = handler([attrName, expression.consequent.value]);
    }
    if (types.isStringLiteral(expression.alternate)) {
        alternateStyle = handler([attrName, expression.alternate.value]);
    }
    return { consequentStyle, alternateStyle };
};
const createConditionalStyleObject = (consequentStyle, alternateStyle, test, types) => {
    const styleKeys = [...new Set([
            ...Object.keys(consequentStyle),
            ...Object.keys(alternateStyle)
        ])];
    const styleProperties = styleKeys
        .map(key => createStyleProperty(key, consequentStyle, alternateStyle, test, types))
        .filter((prop) => prop !== null);
    return types.objectExpression(styleProperties);
};
const createStyleProperty = (key, consequentStyle, alternateStyle, test, types) => {
    const consequentValue = consequentStyle[key];
    const alternateValue = alternateStyle[key];
    if (typeof consequentValue === 'number' && typeof alternateValue === 'number') {
        return types.objectProperty(types.stringLiteral(key), types.conditionalExpression(test, types.numericLiteral(consequentValue), types.numericLiteral(alternateValue)));
    }
    if (typeof consequentValue === 'string' && typeof alternateValue === 'string') {
        return types.objectProperty(types.stringLiteral(key), types.conditionalExpression(test, types.stringLiteral(consequentValue), types.stringLiteral(alternateValue)));
    }
    return null;
};
//# sourceMappingURL=conditionalExpressionProcessor.js.map