"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processJSXElements = void 0;
const templateLiteralProcessor_1 = require("./templateLiteralProcessor");
const conditionalExpressionProcessor_1 = require("./conditionalExpressionProcessor");
const styleAttributeManager_1 = require("./styleAttributeManager");
const processAttributes_1 = require("./processAttributes");
const generateStyleHash_1 = require("./generateStyleHash");
const findConditionalAttributes_1 = require("./findConditionalAttributes");
const getElementInfo_1 = require("./getElementInfo");
const processJSXElements = (path, patterns, styles, styleSheetName, types, prefix) => {
    path.traverse({
        JSXElement(elementPath) {
            if (!types.isJSXElement(elementPath.node))
                return;
            const { openingElement, attributes } = (0, getElementInfo_1.getElementInfo)(elementPath.node, types);
            const conditionalAttrs = (0, findConditionalAttributes_1.findConditionalAttributes)(attributes, types);
            if (conditionalAttrs.length > 0) {
                let combinedStyleExpr = types.objectExpression([]);
                for (const attr of conditionalAttrs) {
                    if (!types.isJSXIdentifier(attr.name))
                        continue;
                    const attrName = attr.name.name;
                    const attrValue = attr.value;
                    if (!types.isJSXExpressionContainer(attrValue))
                        continue;
                    const expression = attrValue.expression;
                    if (types.isTemplateLiteral(expression)) {
                        combinedStyleExpr = (0, templateLiteralProcessor_1.processTemplateLiteral)(expression, attrName, patterns, types, combinedStyleExpr);
                    }
                    else if (types.isConditionalExpression(expression)) {
                        const conditionalStyle = (0, conditionalExpressionProcessor_1.processConditionalExpression)(expression, attrName, patterns, types);
                        if (conditionalStyle) {
                            combinedStyleExpr.properties.push(...conditionalStyle.properties);
                        }
                    }
                    const attrIndex = attributes.indexOf(attr);
                    if (attrIndex > -1) {
                        attributes.splice(attrIndex, 1);
                    }
                }
                if (combinedStyleExpr.properties.length > 0) {
                    (0, styleAttributeManager_1.manageStyleAttribute)(attributes, combinedStyleExpr, types, openingElement);
                    return;
                }
            }
            const newStyles = (0, processAttributes_1.processAttributes)(attributes, types, patterns);
            if (!newStyles)
                return;
            const styleId = (0, generateStyleHash_1.generateStyleHash)(newStyles, prefix);
            styles[styleId] = newStyles;
            const styleExpr = types.memberExpression(types.identifier(styleSheetName), types.identifier(styleId));
            (0, styleAttributeManager_1.manageStyleAttribute)(attributes, styleExpr, types, openingElement);
        }
    });
};
exports.processJSXElements = processJSXElements;
//# sourceMappingURL=processJSXElements.js.map