"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processTemplateLiteral = void 0;
const processTemplateLiteral = (expression, attrName, patterns, types, combinedStyleExpr) => {
    const values = expression.quasis.map(q => q.value.raw.trim()).filter(Boolean);
    const dynamicExpressions = expression.expressions;
    for (const [matcher, handler] of patterns) {
        if (typeof matcher === 'string' && attrName === matcher) {
            const fullValue = buildFullValue(values, dynamicExpressions, types);
            if (typeof handler === 'function') {
                dynamicExpressions.forEach(expr => {
                    if (types.isConditionalExpression(expr)) {
                        combinedStyleExpr = addConditionalProperties(expr, fullValue, handler, types, combinedStyleExpr);
                    }
                });
            }
        }
    }
    return combinedStyleExpr;
};
exports.processTemplateLiteral = processTemplateLiteral;
const buildFullValue = (values, dynamicExpressions, types) => {
    return values.reduce((acc, val, index) => {
        const dynamicPart = dynamicExpressions[index]
            ? (types.isConditionalExpression(dynamicExpressions[index])
                ? dynamicExpressions[index]
                : null)
            : null;
        return acc + val + (dynamicPart ? ' ' : '');
    }, '');
};
const addConditionalProperties = (expr, fullValue, handler, types, combinedStyleExpr) => {
    const consequentStyle = types.isStringLiteral(expr.consequent)
        ? handler(['style', `${fullValue} ${expr.consequent.value}`])
        : {};
    const alternateStyle = types.isStringLiteral(expr.alternate)
        ? handler(['style', `${fullValue} ${expr.alternate.value}`])
        : {};
    const styleKeys = [...new Set([
            ...Object.keys(consequentStyle),
            ...Object.keys(alternateStyle)
        ])];
    styleKeys.forEach(key => {
        const consequentValue = consequentStyle[key];
        const alternateValue = alternateStyle[key];
        if (consequentValue && alternateValue) {
            combinedStyleExpr.properties.push(types.objectProperty(types.stringLiteral(key), types.conditionalExpression(expr.test, createValueExpression(consequentValue, types), createValueExpression(alternateValue, types))));
        }
    });
    return combinedStyleExpr;
};
const createValueExpression = (value, types) => {
    if (typeof value === 'number') {
        return types.numericLiteral(value);
    }
    if (typeof value === 'string') {
        return types.stringLiteral(value);
    }
    return types.stringLiteral('');
};
//# sourceMappingURL=templateLiteralProcessor.js.map